#ifndef _ADVSETTINGSDLG_H_
#define _ADVSETTINGSDLG_H_

#include <QDialog>

class QSettings;
class QPushButton;
class QVBoxLayout;
class QHBoxLayout;
class SettingsTable;

class AdvSettingsDlg : public QDialog
{
    Q_OBJECT

public:
    AdvSettingsDlg(QWidget *parent = 0);
    ~AdvSettingsDlg();

private:
    void refreshList();
    void setDefaults();

private slots:
    void showResetQuery();
    void save();

private:
    QHBoxLayout *layout;
    QVBoxLayout *btnLayout;
    QSettings *settings;
    QPushButton *resetBtn;
    QPushButton *saveBtn;
    SettingsTable *table;
};

#endif // _ADVSETTINGSDLG_H_

